/*
 *	HeNCE Tool
 *
 *	symtab.h - Interface for symbol table stuff.
 *
 *	Sep 1991  Robert Manchek  manchek@CS.UTK.EDU.
 *
 *	Revision Log
 *
$Log: symtab.h,v $
 * Revision 1.2  1992/04/08  06:50:01  moore
 * incorporates changes up to 8 April 1992
 *
 *
 */

struct symval {
	int ival;
};

extern Tree st_New();

extern void st_Free();

extern int st_Lookup();

extern int st_Insert();

extern char *st_Key ();
